#
# spec file for package opam
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           opam
Version:        2.1.5
Release:        1.9
Summary:        Source-based package manager for OCaml
License:        LGPL-2.1-only WITH OCaml-LGPL-linking-exception
Group:          System/Packages
URL:            https://opam.ocaml.org/
Source:         %name-%version.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  ocaml
BuildRequires:  ocaml-cppo
BuildRequires:  ocaml-dune
BuildRequires:  ocaml-rpm-macros >= 20230101
BuildRequires:  ocamlfind(base64)
BuildRequires:  ocamlfind(bigarray)
BuildRequires:  ocamlfind(cmdliner)
BuildRequires:  ocamlfind(cudf)
BuildRequires:  ocamlfind(dose3)
BuildRequires:  ocamlfind(mccs)
BuildRequires:  ocamlfind(ocamlgraph)
BuildRequires:  ocamlfind(opam-file-format)
BuildRequires:  ocamlfind(re)
BuildRequires:  ocamlfind(unix)

Requires:       %name-installer%{?_isa} = %version-%release

Requires:       bubblewrap

# https://cygwin.com/ml/cygwin/2018-01/msg00079.html
Requires:       bzip2
Requires:       curl
Requires:       diffutils
Requires:       gzip
Requires:       patch
Requires:       tar
Requires:       unzip
Recommends:     gcc
Recommends:     make
Recommends:     m4
Recommends:     rsync
Recommends:     git
Recommends:     mercurial
Suggests:       ocaml

%description
OPAM is a source-based package manager for OCaml. It supports multiple
simultaneous compiler installations, flexible package constraints, and a
Git-friendly development workflow.

%package installer
Summary:        Standalone tool for opam install files
Group:          System/Packages
Requires:       %name = %version-%release

%description installer
Handles (un)installation of package files following instructions from
OPAM *.install files.

%package        devel
Summary:        Development files for %name
Group:          Development/Languages/OCaml
Requires:       %name = %version

%description    devel
The %name-devel package contains libraries and signature files for
developing applications that use %name.

%prep
%autosetup -p1

%build
# wipe bogus FETCH
grep -n FETCH configure.ac
sed -i~ '/FETCH/d;287,+7d' configure.ac
diff -u "$_"~ "$_" && exit 1
export DUNE=$(type -P dune)
export CPPO=$(type -P cppo)
export PATCH=$(type -P false)
export BUNZIP2=$(type -P false)
autoreconf -fi
%configure
dune_release_pkgs='opam-admin,opam-client,opam-core,opam-format,opam-installer,opam-repository,opam-solver,opam-state,opam'
%ocaml_dune_setup
%ocaml_dune_build

%install
%ocaml_dune_install
%ocaml_create_file_list

%files -f %name.files
%_bindir/opam
%_bindir/opam-admin.top
%_mandir/man*/*

%files devel -f %name.files.devel

%files installer
%_bindir/opam-installer

%changelog
* Fri May  5 2023 ohering@suse.de
- Update to version 2.1.5
  See included CHANGES for details
* Sun Jan  1 2023 ohering@suse.de
- Update to version 2.1.4
  See included CHANGES for details
- Remove obsolete opam.patch
* Tue Aug  2 2022 ohering@suse.de
- Update to version 2.1.3
  See included CHANGES for details
- Require base64, instead of silently relying on extlib
* Mon Apr  4 2022 ohering@suse.de
- Update to version 2.1.2
  See included CHANGES for details
* Fri Nov  5 2021 ohering@suse.de
- Update to version 2.1.1
  See included CHANGES for details
* Sat Sep 11 2021 ohering@suse.de
- Update to version 2.1.0
  See included CHANGES for details
  refresh opam.patch
* Thu Jan 21 2021 ohering@suse.de
- Update to 2.0.8, via _service file
  See included CHANGES for details
* Sun Apr 12 2020 ohering@suse.de
- Update to 2.0.7, via _service file
  See included CHANGES for details
* Sat Feb 29 2020 ohering@suse.de
- use opam.patch to make opam compatible with the dose3 dune branch
* Thu Jan 16 2020 ohering@suse.de
- Update to 2.0.6, via _service file
  See included CHANGES for details
* Fri Nov  1 2019 ohering@suse.de
- Require current dune macros
- Update to 2.0.5, via _service file
  See included CHANGES for details
* Wed Mar 20 2019 andy@onthewings.net
- Add runtime dependencies for opam switch to work (bsc#1129582).
* Fri Mar  8 2019 andy@onthewings.net
- Build with built-in mccs.
* Mon Feb 18 2019 andy@onthewings.net
- Install dune-package file.
* Mon Feb  4 2019 andy@onthewings.net
- Update to 2.0.3.
  * Various new features and bug fixes.
  * Changed license to LGPL 2.1 with linking exception.
  * For details, see
    https://github.com/ocaml/opam/blob/master/CHANGES
- Removed no-longer-needed newer-deps.patch.
* Tue Apr 17 2018 andy@onthewings.net
- Rename to opam.
* Mon Apr 16 2018 andy@onthewings.net
- Initial packaging.
